==> apache-tinkerpop-3.5.2-src.zip: tinkerpop-3.5.2/gremlin-dotnet/src/Gremlin.Net/Structure/IO/GraphBinary/Types/CustomTypeSerializer.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.IO;
using System.Threading.Tasks;

namespace Gremlin.Net.Structure.IO.GraphBinary.Types
{
    /// <summary>
    /// The interface to implement for serializers of custom types.
    /// </summary>
    public abstract class CustomTypeSerializer : ITypeSerializer
    {
        /// <summary>
        /// Gets the custom type name.
        /// </summary>
        public abstract string TypeName { get; }

        /// <inheritdoc />
        public DataType DataType => DataType.Custom;

        /// <inheritdoc />
        public abstract Task WriteAsync(object value, Stream stream, GraphBinaryWriter writer);

        /// <inheritdoc />
        public abstract Task WriteValueAsync(object value, Stream stream, GraphBinaryWriter writer, bool nullable);

        /// <inheritdoc />
        public abstract Task<object> ReadAsync(Stream stream, GraphBinaryReader reader);

        /// <inheritdoc />
        public abstract Task<object> ReadValueAsync(Stream stream, GraphBinaryReader reader, bool nullable);
    }
}

==> apache-tinkerpop-3.6.8-src.zip: tinkerpop-3.6.8/gremlin-dotnet/src/Gremlin.Net/Structure/IO/GraphBinary/Types/CustomTypeSerializer.cs <==
﻿#region License

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#endregion

using System.IO;
using System.Threading;
using System.Threading.Tasks;

namespace Gremlin.Net.Structure.IO.GraphBinary.Types
{
    /// <summary>
    /// The interface to implement for serializers of custom types.
    /// </summary>
    public abstract class CustomTypeSerializer : ITypeSerializer
    {
        /// <summary>
        /// Gets the custom type name.
        /// </summary>
        public abstract string TypeName { get; }

        /// <inheritdoc />
        public DataType DataType => DataType.Custom;

        /// <inheritdoc />
        public abstract Task WriteAsync(object value, Stream stream, GraphBinaryWriter writer,
            CancellationToken cancellationToken = default);

        /// <inheritdoc />
        public abstract Task WriteValueAsync(object value, Stream stream, GraphBinaryWriter writer, bool nullable,
            CancellationToken cancellationToken = default);

        /// <inheritdoc />
        public abstract Task<object> ReadAsync(Stream stream, GraphBinaryReader reader,
            CancellationToken cancellationToken = default);

        /// <inheritdoc />
        public abstract Task<object> ReadValueAsync(Stream stream, GraphBinaryReader reader, bool nullable,
            CancellationToken cancellationToken = default);
    }
}
